@@ -25,6 +25,11 @@
 
 #include <string.h>
 #include <ctype.h>
+#include <stdlib.h>
+#include <stdarg.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 
 #include "buffer.h"
 
@@ -87,6 +92,23 @@ cherokee_buffer_add (cherokee_buffer_t  *buf, char *txt, int size)
 }
 
 
+ret_t 
+cherokee_buffer_add_va (cherokee_buffer_t  *buf, char *format, ...)
+{
+	int len;
+	va_list ap;
+	CHEROKEE_TEMP (tmp, 200);
+
+	va_start (ap, format);
+	len = vsnprintf (tmp, tmp_size, format, ap);
+	va_end (ap);
+
+	if (len >= 199) return ret_error;
+
+	return cherokee_buffer_add (buf, tmp, len);
+}
+
+
 ret_t
 cherokee_buffer_prepend (cherokee_buffer_t  *buf, char *txt, int size)
 {
@@ -211,6 +233,53 @@ cherokee_buffer_crc32 (cherokee_buffer_t  *buf)
 }
 
 
+ret_t 
+cherokee_buffer_read_file (cherokee_buffer_t *buf, char *filename)
+{
+	int r, ret, f;
+	int remain;
+	struct stat info;
+
+	/* Stat() the file
+	 */
+	r = stat (filename, &info);
+	if (r != 0) return ret_error;
+
+	/* Is a regular file?
+	 */
+	if (S_ISREG(info.st_mode) == 0) {
+		return ret_error;
+	}
+
+	/* Maybe get memory
+	 */
+	remain = buf->size - buf->len;
+	ret = cherokee_buffer_ensure_size (buf, info.st_size - remain + 1);
+	if (ret != ret_ok) return ret;
+	
+	/* Open the file
+	 */
+	f = open (filename, O_RDONLY);
+	if (f < 0) return ret_error;
+
+	/* Read the content
+	 */
+	r = buf->len;
+	buf->len = read (f, buf->buf+r, info.st_size);
+	if (buf->len < 0) {
+		buf->len = 0;
+		return ret_error;
+	}
+	buf->len += r;
+	
+	/* Close it and exit
+	 */
+	close(f);
+
+	return ret_ok;
+}
+
+
 ret_t
 cherokee_buffer_print_debug (cherokee_buffer_t *buf, int len)
 {
