@@ -43,6 +43,9 @@ ret_t cherokee_buffer_free          (cherokee_buffer_t  *buf);
 ret_t cherokee_buffer_clean         (cherokee_buffer_t  *buf);
 
 ret_t cherokee_buffer_add           (cherokee_buffer_t  *buf, char *txt, int size);
+ret_t cherokee_buffer_add_va        (cherokee_buffer_t  *buf, char *format, ...);
+ret_t cherokee_buffer_read_file     (cherokee_buffer_t  *buf, char *filename);
+
 ret_t cherokee_buffer_prepend       (cherokee_buffer_t  *buf, char *txt, int size);
 
 ret_t cherokee_buffer_move_to_begin (cherokee_buffer_t  *buf, int pos);
