@@ -23,15 +23,19 @@
  * USA
  */
 
-#include <varargs.h>
+#include <stdarg.h>
+#include <stdlib.h>
+#include <string.h>
+#include <dlfcn.h>
+
 #include "common.h"
+#include "log.h"
 
 /* Global mini-buffer for quickly use
  */
 char gbl_buffer[gbl_buffer_size];
 
 
-
 /* char *  */
 /* stristr (char * s1, char * s2) */
 /* { */
@@ -69,9 +73,64 @@ hexit (char c)
 	return 0;           
 }
 
+
 void 
 PRINT_ERROR (const char *format, ...)
 {
-	va_list l;
-	fprintf (stderr, format, l);
+	va_list arg_list;
+	
+	va_start(arg_list, format);
+
+	/* Print in the stderr and in the log
+	 */
+	vfprintf(stderr, format, arg_list);
+
+#ifdef HAVE_VSYSLOG
+	vsyslog (LOG_ERR, format, arg_list);
+#endif /* HAVE_VSYSLOG */
+
+	va_end(arg_list);
+}
+
+
+
+
+/* This function is licenced under:
+ * The Apache Software License, Version 1.1
+ *
+ * Copyright (c) 2000-2003 The Apache Software Foundation.  All rights
+ * reserved.
+ */
+char *
+apr_strfsize(size_t size, char *buf)
+{
+    const char ord[] = "KMGTPE";
+    const char *o = ord;
+    int remain;
+
+    if (size < 0) {
+        return strcpy(buf, "  - ");
+    }
+    if (size < 973) {
+        sprintf(buf, "%3d ", (int) size);
+        return buf;
+    }
+    do {
+        remain = (int)(size & 1023);
+        size >>= 10;
+        if (size >= 973) {
+            ++o;
+            continue;
+        }
+        if (size < 9 || (size == 9 && remain < 973)) {
+            if ((remain = ((remain * 5) + 256) / 512) >= 10)
+                ++size, remain = 0;
+            sprintf(buf, "%d.%d%c", (int) size, remain, *o);
+            return buf;
+        }
+        if (remain >= 512)
+            ++size;
+        sprintf(buf, "%3d%c", (int) size, *o);
+        return buf;
+    } while (1);
 }
