@@ -47,6 +47,7 @@
 #include "buffer.h"
 #include "plugin_table_entry.h"
 #include "encoder_table.h"
+#include "server.h"
 
 ret_t
 cherokee_connection_new  (cherokee_connection_t **cnt)
@@ -63,6 +64,7 @@ cherokee_connection_new  (cherokee_connection_t **cnt)
 	n->version         = http_version_unknown;
 	n->handler         = NULL; 
 	n->encoder         = NULL;
+	n->arguments       = NULL;
 	n->logger_ref      = NULL;
 	n->keep_alive      = 0;
 	n->timeout         = time(NULL) + 15;   // CHECK ME !!
@@ -74,6 +76,7 @@ cherokee_connection_new  (cherokee_connection_t **cnt)
 	cherokee_buffer_new (&n->request);
 	cherokee_buffer_new (&n->redirect);
 	cherokee_buffer_new (&n->host);
+	cherokee_buffer_new (&n->query_string);
 
 	cherokee_socket_new (&n->socket);
 
@@ -104,8 +107,9 @@ cherokee_connection_free (cherokee_connection_t  *cnt)
 	   cherokee_buffer_free (cnt->redirect);
 	   cherokee_buffer_free (cnt->host);
 
-	   if(cnt->query_string) {
-		   cherokee_buffer_free(cnt->query_string);
+	   if (cnt->arguments) {
+		   cherokee_table_free2 (cnt->arguments, free);
+		   cnt->arguments = NULL;
 	   }
 
 	   free (cnt);
@@ -116,15 +120,15 @@ cherokee_connection_free (cherokee_connection_t  *cnt)
 ret_t
 cherokee_connection_clean (cherokee_connection_t *cnt)
 {	   
-	   cnt->phase       = phase_reading_header;
-	   cnt->version     = http_version_unknown;
-	   cnt->method      = http_unknown;
-	   cnt->error_code  = http_ok;
-	   cnt->timeout     = -1;
-	   cnt->range_start = 0;
-	   cnt->range_end   = 0;
-	   cnt->logger_ref  = NULL;
-	   cnt->tcp_cork    = 0;
+	   cnt->phase        = phase_reading_header;
+	   cnt->version      = http_version_unknown;
+	   cnt->method       = http_unknown;
+	   cnt->error_code   = http_ok;
+	   cnt->timeout      = -1;
+	   cnt->range_start  = 0;
+	   cnt->range_end    = 0;
+	   cnt->logger_ref   = NULL;
+	   cnt->tcp_cork     = 0;
 
 	   if (cnt->handler != NULL) {
 		   cherokee_handler_free (cnt->handler);
@@ -142,6 +146,12 @@ cherokee_connection_clean (cherokee_connection_t *cnt)
 	   cherokee_buffer_clean (cnt->request);
 	   cherokee_buffer_clean (cnt->redirect);
 	   cherokee_buffer_clean (cnt->host);
+	   cherokee_buffer_clean (cnt->query_string);
+
+	   if (cnt->arguments) {
+		   cherokee_table_free2 (cnt->arguments, free);
+		   cnt->arguments = NULL;
+	   }
 
 	   return ret_ok;
 }
@@ -188,7 +198,7 @@ add_error_code_string_to_buffer (cherokee_connection_t *cnt)
 
 
 ret_t
-cherokee_connection_send_header (cherokee_connection_t  *cnt, int hideversion)
+cherokee_connection_send_header (cherokee_connection_t *cnt)
 {
 	int ret;
 	
@@ -214,10 +224,12 @@ cherokee_connection_send_header (cherokee_connection_t  *cnt, int hideversion)
 
 	/* Add server name
 	 */
-	if (hideversion) {
-		cherokee_buffer_add (cnt->buffer, "Server: Cherokee" CRLF, 16+2);
-	} else {
-		cherokee_buffer_add (cnt->buffer, "Server: Cherokee/" VERSION CRLF, 17+5+2);
+	if (CONN_SRV(cnt)->hideservername == 0) {
+		if (CONN_SRV(cnt)->hideversion) {
+			cherokee_buffer_add (cnt->buffer, "Server: Cherokee" CRLF, 16+2);
+		} else {
+			cherokee_buffer_add (cnt->buffer, "Server: Cherokee/" VERSION CRLF, 17+5+2);
+		}
 	}
 
 	/* Redirected connections
@@ -581,24 +593,12 @@ get_uri (cherokee_connection_t *cnt)
 		return ret_error;
 	}
 	
-	/* Check the parameters
+	/* Look for the QueryString
 	 */
-	ptr = index (cnt->buffer->buf + begin, '?');
-	if (ptr != NULL) {
-		int qs_len;
-
-		/* Save the query string  */
-		++ptr;
-		qs_len = strcspn(ptr, "\n\r ");
-
-		cherokee_buffer_new(&cnt->query_string);
-		cherokee_buffer_add(cnt->query_string, ptr, qs_len);
-
-		/* Sets the end to the filename */
-		end = ptr - cnt->buffer->buf - 1;
-
-	} else {
-		cnt->query_string = NULL;
+	cnt->qs_begin_ref = index (cnt->buffer->buf + begin, '?');
+	if (cnt->qs_begin_ref != NULL) {
+		end = cnt->qs_begin_ref - cnt->buffer->buf;
+		cnt->qs_begin_ref++;
 	}
 
 	/* Dup the request
@@ -631,7 +631,6 @@ int inline
 cherokee_connection_is_userdir (cherokee_connection_t *cnt)
 {
 	return ((cnt->request->len > 4) && (cnt->request->buf[1] == '~'));
-
 }
 
 
@@ -918,6 +917,62 @@ cherokee_connection_parse_header (cherokee_connection_t *cnt, cherokee_encoder_t
 }
 
 
+
+/* cherokee_connection_parse_args:
+ *  Process the incoming parameters.
+ *
+ *  1.- Build cnt->arguments
+ *  2.- Build cnt->query_string
+ */
+ret_t 
+cherokee_connection_parse_args (cherokee_connection_t *cnt)
+{
+	int  len;
+	char tmp_end;
+	char *string, *token;
+
+	if (cnt->qs_begin_ref == NULL) {
+		return ret_ok;
+	}
+
+	if (cnt->arguments != NULL) {
+		return ret_error;
+	}
+
+	/* Look for the end
+	 */
+	len = strcspn (cnt->qs_begin_ref, "\n\r ");
+	cherokee_buffer_add (cnt->query_string, cnt->qs_begin_ref, len);
+
+	/* Parse the parameters
+	 */
+	string = cnt->query_string->buf;
+	while ((token = strtok(string, "&")) != NULL) 
+	{
+		char *equ, *key, *val;
+		string = NULL;
+
+		if (equ = index (token, '='))
+		{
+			*equ = '\0';
+
+			key = token;
+			val = equ+1;
+
+			// printf ("key='%s' val='%s'\n", key, val);
+			cherokee_table_add (cnt->arguments, key, val);
+
+			*equ = '=';			
+		} else {
+			// printf ("key='%s'\n", token);
+			cherokee_table_add (cnt->arguments, token, NULL);
+		}
+	}
+
+	return ret_ok;
+}
+
+
 ret_t
 cherokee_connection_open_request (cherokee_connection_t *cnt)
 {	
@@ -933,7 +988,7 @@ cherokee_connection_open_request (cherokee_connection_t *cnt)
 
 
 ret_t
-cherokee_connection_send_response_page (cherokee_connection_t *cnt, int hideversion)
+cherokee_connection_send_response_page (cherokee_connection_t *cnt)
 {
 	   ret_t  ret;
 	   
@@ -974,10 +1029,12 @@ cherokee_connection_send_response_page (cherokee_connection_t *cnt, int hidevers
 	   
 	   /* Add page foot
 	    */
-	   if (hideversion) {
-		   cherokee_buffer_add (cnt->buffer, "<p><hr><address>Cherokee web server " VERSION "</address></body></html>" CRLF, 67); 
-	   } else {
-		   cherokee_buffer_add (cnt->buffer, "<p><hr><address>Cherokee web server </address></body></html>" CRLF, 62); 
+	   if (CONN_SRV(cnt)->hideservername == 0) {
+		   if (CONN_SRV(cnt)->hideversion) {
+			   cherokee_buffer_add (cnt->buffer, "<p><hr><address>Cherokee web server " VERSION "</address></body></html>" CRLF, 67); 
+		   } else {
+			   cherokee_buffer_add (cnt->buffer, "<p><hr><address>Cherokee web server </address></body></html>" CRLF, 62); 
+		   }
 	   }
    
 	   /* Send it
