@@ -71,6 +71,11 @@ typedef struct {
 	cherokee_http_method_t        method;
 
 	cherokee_encoder_t           *encoder;
+	
+	char                         *qs_begin_ref;
+	cherokee_buffer_t            *query_string;	
+	cherokee_table_t             *arguments;
+
 	cherokee_logger_t            *logger_ref;
 	int                           log_at_end;
 
@@ -87,7 +92,6 @@ typedef struct {
 	cherokee_buffer_t            *local_directory;  /* /var/www/  or  /home/alo/public_html/ */
 	cherokee_buffer_t            *web_directory;    /* /cherokee/ */
 	cherokee_buffer_t            *request;          /* /dir/file */
-	cherokee_buffer_t            *query_string;
 	cherokee_buffer_t            *host;
 
 	time_t                        timeout;
@@ -120,8 +124,8 @@ ret_t cherokee_connection_close (cherokee_connection_t *cnt);
 
 /* 	Sending
  */
-ret_t cherokee_connection_send_header        (cherokee_connection_t *cnt, int hideversion);
-ret_t cherokee_connection_send_response_page (cherokee_connection_t *cnt, int hideversion);
+ret_t cherokee_connection_send_header        (cherokee_connection_t *cnt);
+ret_t cherokee_connection_send_response_page (cherokee_connection_t *cnt);
 
 /*	Iteration
  */
@@ -129,20 +133,21 @@ ret_t cherokee_connection_open_request  (cherokee_connection_t *cnt);
 ret_t cherokee_connection_reading_check (cherokee_connection_t *cnt);
 ret_t cherokee_connection_step          (cherokee_connection_t *cnt);
 
-ret_t cherokee_connection_get_plugin_entry (cherokee_connection_t  *cnt, cherokee_plugin_table_t *plugins, cherokee_plugin_table_entry_t **plugin_entry);
-ret_t cherokee_connection_create_handler   (cherokee_connection_t  *cnt, cherokee_plugin_table_entry_t *plugin_entry);
+ret_t cherokee_connection_get_plugin_entry (cherokee_connection_t *cnt, cherokee_plugin_table_t *plugins, cherokee_plugin_table_entry_t **plugin_entry);
+ret_t cherokee_connection_create_handler   (cherokee_connection_t *cnt, cherokee_plugin_table_entry_t *plugin_entry);
 
 /* 	Headers
  */
-int   cherokee_connection_eoh          (cherokee_connection_t  *cnt);
-ret_t cherokee_connection_get_request  (cherokee_connection_t  *cnt);
-ret_t cherokee_connection_parse_header (cherokee_connection_t  *cnt, cherokee_encoder_table_t *encoders);
+int   cherokee_connection_eoh          (cherokee_connection_t *cnt);
+ret_t cherokee_connection_get_request  (cherokee_connection_t *cnt);
+ret_t cherokee_connection_parse_header (cherokee_connection_t *cnt, cherokee_encoder_table_t *encoders);
+ret_t cherokee_connection_parse_args   (cherokee_connection_t *cnt);
 
 
 /* 	Log
  */
-ret_t cherokee_connection_log_or_delay (cherokee_connection_t  *cnt);
-ret_t cherokee_connection_log_delayed  (cherokee_connection_t  *cnt);
+ret_t cherokee_connection_log_or_delay (cherokee_connection_t *cnt);
+ret_t cherokee_connection_log_delayed  (cherokee_connection_t *cnt);
 
 
 int   cherokee_connection_is_userdir                    (cherokee_connection_t  *cnt);
