@@ -43,7 +43,7 @@ static char gzip_header[gzip_header_len] = {0x1F, 0x8B,
 ret_t 
 cherokee_encoder_gzip_new (cherokee_encoder_gzip_t **encoder)
 {
-	cherokee_encoder_gzip_t *n = (cherokee_encoder_gzip_t *) malloc (sizeof(cherokee_encoder_gzip_t));
+	CHEROKEE_NEW_STRUCT (n, encoder_gzip);
 
 	cherokee_encoder_init_base (ENCODER(n));
 
