@@ -31,49 +31,67 @@
 #include "handler_common.h"
 #include "handler_file.h"
 #include "handler_dirlist.h"
-
+#include "server.h"
+#include "list_ext.h"
 
 ret_t 
 cherokee_handler_common_new (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *properties)
 {
-	struct stat  info;
-	char        *request;
+	struct stat            info;
+	cherokee_connection_t *conn = CONN(cnt);
+	cherokee_server_t     *srv  = CONN_SRV(cnt);
 
-	/* Yeah, yeah..
-	 * This is very ugly, I know.. ;(
-	 */
-	request = CONN(cnt)->request_local;
+	cherokee_buffer_add (conn->local_directory, conn->request->buf, conn->request->len);
 
 	/* Request is a directory
 	 */
-	if ((stat (request, &info) == 0) && S_ISDIR(info.st_mode)) {
-		char *new;
-		int   len;
-		ret_t ret;
+	if ((stat (conn->local_directory->buf, &info) == 0) && S_ISDIR(info.st_mode)) {
+		list_t *i;
 
-		/* Look for an index file
+		/* Have an index file inside?
 		 */
-		len = strlen (request);
-		new = (char *) malloc (len + 12);
-		sprintf (new, "%s/index.html", request);
-		
-		if ((stat (new, &info) == 0) && S_ISREG(info.st_mode)) {
-			/* Sucks again :-((
+		list_for_each (i, &srv->index_list) {
+			int   is_file, exists;
+			char *index     = LIST_ITEM_INFO(i);
+			int   index_len = strlen (index);
+			
+			/* Add the index file
 			 */
-			free (CONN(cnt)->request_local);
-			CONN(cnt)->request_local = new;
-			return cherokee_handler_file_new (hdl, cnt, properties);
-		} else {
-			ret = cherokee_handler_dirlist_new (hdl, cnt, properties);
+			cherokee_buffer_add (conn->local_directory, index, index_len);
+			
+			/* stat() it
+			 */
+			exists = (stat (conn->local_directory->buf, &info) == 0);
+			
+			/* Drop the index filename
+			 */
+			cherokee_buffer_drop_endding (conn->local_directory, index_len);
+
+			/* If the file doesn't exist, go and try with the next one
+			 */
+			if (! exists) {
+				continue;
+			}
+
+			cherokee_buffer_drop_endding (conn->local_directory, conn->request->len);
+			
+			is_file = S_ISREG(info.st_mode);
+			if (is_file) {			
+				cherokee_buffer_add (conn->request, index, index_len);
+				return cherokee_handler_file_new (hdl, cnt, properties);
+			}
 		} 
-		
-		free (new);
-		return ret;
+
+		/* If the dir hasn't a index file, it uses dirlist
+		 */
+		cherokee_buffer_drop_endding (conn->local_directory, conn->request->len);
+		return cherokee_handler_dirlist_new (hdl, cnt, properties);
 	}
 
 
         /* File handler
 	 */
+	cherokee_buffer_drop_endding (conn->local_directory, conn->request->len);
 	return cherokee_handler_file_new (hdl, cnt, properties);
 }
 
