@@ -23,8 +23,8 @@
  * USA
  */
 
-#ifndef __CHEROKEE2_DIRLIST_HANDLER_H__
-#define __CHEROKEE2_DIRLIST_HANDLER_H__
+#ifndef __CHEROKEE_DIRLIST_HANDLER_H__
+#define __CHEROKEE_DIRLIST_HANDLER_H__
 
 #include <dirent.h>
 
@@ -36,12 +36,25 @@
 typedef struct {
 	cherokee_handler_t handler;
 
-	char *request;
-	int   request_len;
-
-	DIR  *dir;
-	
+	DIR  *dir;	
 	int page_begining;
+
+	/* Properties
+	 */
+	char *bgcolor;     /* background color for the document */
+	char *text;        /* color for the text of the document */
+	char *link;        /* color for unvisited hypertext links */
+	char *vlink;       /* color for visited hypertext links */
+	char *alink;       /* color for active hypertext links */
+	char *background;  /* URL for an image to be used to tile the background */
+
+	int show_size;
+	int show_date;
+	int show_owner;
+	int show_group;
+	
+	cherokee_buffer_t *header;
+
 } cherokee_handler_dirlist_t;
 
 #define DHANDLER(x)  ((cherokee_handler_dirlist_t *)(x))
@@ -52,14 +65,14 @@ typedef struct {
 void dirlist_init (void);
 
 
-ret_t cherokee_handler_dirlist_new (cherokee_handler_t **hdl, void *cnt);
+ret_t cherokee_handler_dirlist_new (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *properties);
 
 /* virtual methods implementation
  */
-ret_t cherokee_handler_dirlist_init        (cherokee_handler_dirlist_t *dhdl, char *request, char *request_local);
+ret_t cherokee_handler_dirlist_init        (cherokee_handler_dirlist_t *dhdl);
 ret_t cherokee_handler_dirlist_free        (cherokee_handler_dirlist_t *dhdl);
 ret_t cherokee_handler_dirlist_step        (cherokee_handler_dirlist_t *dhdl, cherokee_buffer_t *buffer);
 ret_t cherokee_handler_dirlist_add_headers (cherokee_handler_dirlist_t *dhdl, cherokee_buffer_t *buffer);
 
 
-#endif /* __CHEROKEE2_DIRLIST_HANDLER_H__ */
+#endif /* __CHEROKEE_DIRLIST_HANDLER_H__ */
