@@ -33,8 +33,17 @@
 #include "handler_file.h"
 #include "connection.h"
 
-#if HAVE_SENDFILE
-#include <sys/sendfile.h>
+#if defined(LINUX_SENDFILE_API) || defined(SOLARIS_SENDFILE_API)
+# include <sys/sendfile.h>
+#elif defined(HPUX_SENDFILE_API)
+# include <sys/socket.h>
+# include <sys/uio.h>
+#elif defined(FREEBSD_SENDFILE_API)
+# include <sys/types.h>
+# include <sys/socket.h>
+# include <sys/uio.h>
+#elif defined(LINUX_BROKEN_SENDFILE_API)
+ extern int32 sendfile (int out_fd, int in_fd, int32 *offset, uint32 count);
 #endif
 
 
@@ -172,10 +181,27 @@ cherokee_handler_file_step (cherokee_handler_file_t *fhdl,
 		ssize_t sent;
 		cherokee_connection_t *conn = CONN(HANDLER(fhdl)->connection);
 		
+
+#ifdef FREEBSD_SENDFILE_API
+		/* FreeBSD sendfile: in_fd and out_fd are reversed
+		 *
+		 * int
+		 * sendfile(int fd, int s, off_t offset, size_t nbytes,
+		 * struct sf_hdtr *hdtr, off_t *sbytes, int flags);
+		 */
+		sent = sendfile (fhdl->fd,                        /* int             fd     */
+				 SOCKET_FD(conn->socket),         /* int             s      */
+				 &fhdl->offset,                   /* off_t           offset */
+				 conn->range_end - fhdl->offset,  /* size_t          nbytes */
+				 NULL,                            /* struct sf_hdtr *hdtr   */
+				 &fhdl->offset,                   /* off_t          *sbytes */ 
+				 0);                              /* int             flags  */
+#else
 		sent = sendfile (SOCKET_FD(conn->socket),         /* int    out_fd */
-				 fhdl->fd,                        /* int     in_fd */
+				 fhdl->fd,                        /* int    in_fd  */
 				 &fhdl->offset,                   /* off_t *offset */
-				 conn->range_end - fhdl->offset); /* size_t  count */
+				 conn->range_end - fhdl->offset); /* size_t count  */
+#endif
 
 		/* cherokee_handler_file_init() activated the TCP_CORK flags.
 		 * After it, the header was sent.  And now, the first
