@@ -23,8 +23,8 @@
  * USA
  */
 
-#ifndef __CHEROKEE2_CONNECTION_HANDLER_FILE_H__
-#define __CHEROKEE2_CONNECTION_HANDLER_FILE_H__
+#ifndef __CHEROKEE_CONNECTION_HANDLER_FILE_H__
+#define __CHEROKEE_CONNECTION_HANDLER_FILE_H__
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -43,6 +43,11 @@ typedef struct {
 	off_t        offset;
 	struct stat  info;
 	char        *mime;
+
+#if HAVE_SENDFILE
+	int          using_sendfile;
+#endif
+
 } cherokee_handler_file_t;
 
 #define FHANDLER(x)  ((cherokee_handler_file_t *)(x))
@@ -57,9 +62,9 @@ ret_t cherokee_handler_file_new   (cherokee_handler_t **hdl, void *cnt, cherokee
 
 /* virtual methods implementation
  */
-ret_t cherokee_handler_file_init        (cherokee_handler_file_t *hdl, char *request, char *request_local);
+ret_t cherokee_handler_file_init        (cherokee_handler_file_t *hdl);
 ret_t cherokee_handler_file_free        (cherokee_handler_file_t *hdl);
 ret_t cherokee_handler_file_step        (cherokee_handler_file_t *hdl, cherokee_buffer_t *buffer);
 ret_t cherokee_handler_file_add_headers (cherokee_handler_file_t *hdl, cherokee_buffer_t *buffer);
 
-#endif /* __CHEROKEE2_CONNECTION_HANDLER_FILE_H__ */
+#endif /* __CHEROKEE_CONNECTION_HANDLER_FILE_H__ */
