@@ -23,29 +23,41 @@
  * USA
  */
 
-#ifndef __CHEROKEE2_CONNECTION_HANDLER_PHP4_H__
-#define __CHEROKEE2_CONNECTION_HANDLER_PHP4_H__
+#ifndef __CHEROKEE_CONNECTION_HANDLER_PHP4_H__
+#define __CHEROKEE_CONNECTION_HANDLER_PHP4_H__
 
 #include "common.h"
 #include "buffer.h"
 #include "handler.h"
 
+#include "php.h"
+#include "SAPI.h"
+
 
 typedef struct {
-	   cherokee_handler_t handler;
-
+	cherokee_handler_t handler;
+	
+	zend_file_handle *file_handle;
+	zend_llist       *global_vars;
 } cherokee_handler_php4_t;
 
-#define FHANDLER(x)  ((cherokee_handler_php4_t *)(x))
+#define PHPHANDLER(x)  ((cherokee_handler_php4_t *)(x))
 
 
-ret_t cherokee_handler_php4_new   (cherokee_handler_php4_t **hdl, char *request);
+
+/* Library init function
+ */
+void php4_init ();
+
+
+ret_t cherokee_handler_php4_new   (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *properties);
 
 /* virtual methods implementation
  */
-ret_t cherokee_handler_php4_free               (void *hdl);
-ret_t cherokee_handler_php4_step               (void *hdl, cherokee_buffer_t *buffer);
-int   cherokee_handler_php4_get_content_length (void *hdl);
+ret_t cherokee_handler_php4_init        (cherokee_handler_php4_t *hdl);
+ret_t cherokee_handler_php4_free        (cherokee_handler_php4_t *hdl);
+ret_t cherokee_handler_php4_step        (cherokee_handler_php4_t *hdl, cherokee_buffer_t *buffer);
+ret_t cherokee_handler_php4_add_headers (cherokee_handler_php4_t *hdl, cherokee_buffer_t *buffer);
 
 
-#endif /* __CHEROKEE2_CONNECTION_HANDLER_PHP4_H__ */
+#endif /* __CHEROKEE_CONNECTION_HANDLER_PHP4_H__ */
