@@ -28,6 +28,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <stdarg.h>
 
 #include "logger.h"
 
@@ -37,9 +38,12 @@ cherokee_logger_init_base (cherokee_logger_t *logger)
 {
 	/* Pure virtual methods
 	 */
-	logger->init        = NULL;
-	logger->free        = NULL;
-	logger->write       = NULL;
+	logger->init         = NULL;
+	logger->free         = NULL;
+	logger->write_access = NULL;
+	logger->write_error  = NULL;
+
+	cherokee_buffer_new (&logger->buffer);
 	
 	return ret_ok;
 }
@@ -53,30 +57,81 @@ cherokee_logger_init_base (cherokee_logger_t *logger)
 ret_t
 cherokee_logger_free (cherokee_logger_t *logger)
 {
-	if (logger->free)
-		return logger->free (logger);
+	ret_t ret;
+
+	if (logger->buffer) {
+		ret = cherokee_buffer_free (logger->buffer);
+	}
 	
-	return ret_error;
+	if (logger->free == NULL) {
+		return ret_error;
+	}
+
+	ret |= logger->free (logger);
+
+	return ret;
+}
+
+
+ret_t
+cherokee_logger_flush (cherokee_logger_t *logger)
+{
+	ret_t ret = ret_error;
+
+	if (logger->flush) {
+		ret = logger->flush(logger);
+	}
+
+	return ret;
 }
 
 
 ret_t
 cherokee_logger_init (cherokee_logger_t *logger)
 {
-	if (logger->init)
+	if (logger->init) {
 		return logger->init (logger);
+	}
 	
 	return ret_error;
 }
 
 
 inline ret_t
-cherokee_logger_write (cherokee_logger_t *logger, void *conn)
+cherokee_logger_write_access (cherokee_logger_t *logger, void *conn)
 {
-	if (logger->write)
-		return logger->write (logger, conn);
+	if (logger->write_access)
+		return logger->write_access (logger, conn);
 	
 	return ret_error;
 }
 
 
+ret_t 
+cherokee_logger_write_error (cherokee_logger_t *logger, void *conn)
+{
+	if (logger->write_error) {
+		return logger->write_error (logger, conn);
+	}
+
+	return ret_error;
+}
+
+
+ret_t 
+cherokee_logger_write_string (cherokee_logger_t *logger, const char *format, ...)
+{
+	va_list ap;
+
+	if (logger->write_string) {
+		CHEROKEE_TEMP (tmp, 200);
+
+		va_start (ap, format);
+		vsnprintf (tmp, tmp_size, format, ap);
+		va_end (ap);
+
+		return logger->write_string (logger, tmp);
+	}
+
+	return ret_error;
+}
