@@ -93,8 +93,8 @@ cherokee_logger_ncsa_new  (cherokee_logger_t **logger, cherokee_table_t *propert
 	n->errorlog_filename  = NULL;
 
 	if (properties != NULL) {
-		n->accesslog_filename = cherokee_table_get (properties, "AccessLog");
-		n->errorlog_filename  = cherokee_table_get (properties, "ErrorLog");
+		n->accesslog_filename = cherokee_table_get_val (properties, "AccessLog");
+		n->errorlog_filename  = cherokee_table_get_val (properties, "ErrorLog");
 	}
 	
 	return ret_ok;
@@ -116,12 +116,15 @@ cherokee_logger_ncsa_init (cherokee_logger_ncsa_t *logger)
 		PRINT_ERROR("cherokee_logger_ncsa: error opening %s for append\n", logger->accesslog_filename); 
 		return ret_error;
 	}
+	fcntl (fileno (logger->accesslog_fd), F_SETFD, 1);
+	
 
         logger->errorlog_fd  = fopen (logger->errorlog_filename, "a+");
 	if (logger->errorlog_fd == NULL) {
 		PRINT_ERROR("cherokee_logger_ncsa: error opening %s for append\n", logger->errorlog_filename); 
 		return ret_error;
 	}
+	fcntl (fileno (logger->errorlog_fd), F_SETFD, 1);
 
 	return ret_ok;
 }
