@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2002 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2003 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,32 +31,28 @@ cherokee_server_t *srv = NULL;
 
 void
 restart_server (int code)
-{
-	cherokee_server_free (srv);
-
-	cherokee_server_conf_read_file (srv->config, CHEROKEE_CONFDIR"/cherokee.conf");
-
-	cherokee_server_new (&srv);
-	cherokee_server_init (&srv);
+{	
+	cherokee_server_handle_HUP (srv);
+	printf ("Cherokee reloaded\n");
 }
 
-
 int
 main (int argc, char **argv)
 {
 	ret_t ret;
 	
-	
 	ret = cherokee_server_new (&srv);
 	if (ret != ret_ok) return 1;
 	
-	ret = cherokee_server_conf_read_file (srv->config, CHEROKEE_CONFDIR"/cherokee.conf");
+	ret = cherokee_server_read_config_file (srv, CHEROKEE_CONFDIR"/cherokee.conf");
 	if (ret != ret_ok) return 2;
 	
 	signal (SIGPIPE, SIG_IGN);
 	signal (SIGHUP, restart_server);
 	
-	cherokee_server_init (srv);
+	ret = cherokee_server_init (srv);
+	if (ret != ret_ok) return 3;
+
 	for (;;) {
 		cherokee_server_step(srv);
 	}
