@@ -24,18 +24,15 @@
  */
 
 #include "mime.h"
-#include "server_config.h"
 
 
-static int              _mime_is_init = 0;
 static cherokee_mime_t *_mime_global  = NULL;
 
 
 static ret_t 
 cherokee_mime_new  (cherokee_mime_t **mime)
 {
-	   cherokee_mime_t *n = (cherokee_mime_t *) malloc (sizeof(cherokee_mime_t));
-	   return_if_fail (n!=NULL, ret_nomem);
+	   CHEROKEE_NEW_STRUCT(n, mime);
 
 	   cherokee_table_init(&n->table);
 
@@ -58,8 +55,8 @@ static ret_t
 cherokee_mime_load (cherokee_mime_t *mime, char *filename)
 {
 	   FILE   *f;
-	   char    ext[32];
-	   char    mime_string[80];
+	   char    ext[gbl_buffer_size];
+	   char    mime_string[gbl_buffer_size];
 
 	   f = fopen (filename, "r");
 	   return_if_fail (f!=NULL, ret_file_not_found);
@@ -83,7 +80,7 @@ cherokee_mime_load (cherokee_mime_t *mime, char *filename)
 
 			 /* Add to table
 			  */
-			 cherokee_table_add (&mime->table, strdup(ext), strdup(mime_string));
+			 cherokee_table_add (&mime->table, ext, strdup(mime_string));
 	   }
 	   
 	   fclose(f);
@@ -94,7 +91,7 @@ cherokee_mime_load (cherokee_mime_t *mime, char *filename)
 char * 
 cherokee_mime_get (cherokee_mime_t *mime, char *ext)
 {
-	   return cherokee_table_get (&mime->table, ext);
+	return cherokee_table_get_val (&mime->table, ext);
 }
 
 
@@ -106,25 +103,25 @@ cherokee_mime_get_default (cherokee_mime_t **mime)
 }
 
 
-/* 	Library init function
- */
-
-void
-mime_init (void)
+ret_t 
+cherokee_mime_init (cherokee_mime_t **mime)
 {
-	cherokee_server_conf_t *config;
+	return cherokee_mime_init_with_file (mime, CHEROKEE_DATADIR"/mime_types.txt");
+}
 
-	if (_mime_is_init) 
-		return;
-	
+
+ret_t 
+cherokee_mime_init_with_file (cherokee_mime_t **mime, char *filename)
+{
+	if (_mime_global != NULL) {
+		*mime = _mime_global;
+		return ret_ok;
+	}
+
 	cherokee_mime_new (&_mime_global);
-	cherokee_server_conf_get_default (&config);
+	cherokee_mime_load (_mime_global, filename);
 
-	if (config->mimetypes_file != NULL) {
-		cherokee_mime_load (_mime_global, config->mimetypes_file);
-	} else {
-		cherokee_mime_load (_mime_global, CHEROKEE_DATADIR"/mime_types.txt");
-	}
-	
-	_mime_is_init = 1;
+	*mime = _mime_global;
+
+	return ret_ok;
 }
