@@ -61,6 +61,10 @@ cherokee_server_new  (cherokee_server_t **srv)
 	INIT_LIST_HEAD(&n->thread_list);
 	cherokee_thread_new (&n->main_thread, n, 0);
 
+	/* Default Index files list
+	 */
+	INIT_LIST_HEAD(&n->index_list);
+
 	/* Server config
 	 */
 	n->port           = 80;
@@ -69,6 +73,7 @@ cherokee_server_new  (cherokee_server_t **srv)
 	n->timeout        = 15;
 	n->keepalive      = 1;
 	n->hideversion    = 0;
+	n->hideservername = 0;
 	n->mimetypes_file = NULL;
 	n->userdir        = NULL;
 	n->userdir_handler= NULL;
@@ -76,6 +81,9 @@ cherokee_server_new  (cherokee_server_t **srv)
 	n->ncpus          = -1;
 	n->thread_num     = 0;
 
+	n->chroot         = NULL;
+	n->chrooted       = 0;
+
 	n->user_orig      = getuid();
 	n->user           = n->user_orig;
 	n->group_orig     = getgid();
@@ -346,8 +354,18 @@ cherokee_server_init (cherokee_server_t *srv)
 	if (ret != ret_ok) {
 		return ret;
 	}
-
 	
+	/* Chroot
+	 */
+	if (srv->chroot) {
+		srv->chrooted = (chroot (srv->chroot) == 0);
+		if (srv->chrooted == 0) {
+			PRINT_ERROR ("Cannot chroot() to '%s'\n", srv->chroot);
+		}
+	} 
+
+	chdir ("/");
+
 	return ret_ok;
 }
 
@@ -365,6 +383,13 @@ close_all_connections (cherokee_server_t *srv)
 }
 
 
+static void
+for_each_func_free_vserver (const char *key, void *vserver)
+{	
+	cherokee_virtual_server_free (vserver);
+}
+
+
 ret_t 
 cherokee_server_clean (cherokee_server_t *srv)
 {
@@ -389,11 +414,16 @@ cherokee_server_clean (cherokee_server_t *srv)
 		free (srv->userdir);
 		srv->userdir = NULL;
 	}
+
 	if (srv->userdir_handler != NULL) {
 		cherokee_plugin_table_entry_free (srv->userdir_handler);
 		srv->userdir_handler = NULL;
 	}
 
+	if (srv->chroot != NULL) {
+		free (srv->chroot);
+		srv->chroot = NULL;
+	}
 	
 	/* Clean the encoders table
 	 */
@@ -406,13 +436,19 @@ cherokee_server_clean (cherokee_server_t *srv)
 	/* Clean the virtual servers table
 	 */
 	cherokee_virtual_server_clean (srv->vserver_default);
- 
-	// TODO:
-	// Free each vserver
-	cherokee_table_free (srv->vservers);
-	cherokee_table_new (&srv->vservers);
 
-	srv->hideversion = 0;
+	/* Clean the virtual servers table
+	 */
+	cherokee_table_foreach (srv->vservers, for_each_func_free_vserver);
+	cherokee_table_clean (srv->vservers);
+
+	/* Clean the index list
+	 */
+	cherokee_list_free (&srv->index_list, free);
+	INIT_LIST_HEAD(&srv->index_list);
+ 
+	srv->hideversion    = 0;
+	srv->hideservername = 0;
 
 	return ret_ok;
 }
@@ -423,16 +459,18 @@ cherokee_server_free (cherokee_server_t *srv)
 {
 	close (srv->socket);
 
-	cherokee_virtual_server_free (srv->vserver_default);
-	srv->vserver_default = NULL;
-
 	cherokee_encoder_table_free (srv->encoders);
 	cherokee_logger_table_free (srv->loggers);
 
-	// TODO:
-	// Free each vserver
+	cherokee_list_free (&srv->index_list, free);
+
+	/* Virtual servers
+	 */
+	cherokee_virtual_server_free (srv->vserver_default);
+	srv->vserver_default = NULL;
+
+	cherokee_table_foreach (srv->vservers, for_each_func_free_vserver);
 	cherokee_table_free (srv->vservers);
-	cherokee_table_new (&srv->vservers);
 
 
 	if (srv->listen_to != NULL) {
@@ -449,11 +487,17 @@ cherokee_server_free (cherokee_server_t *srv)
 		free (srv->userdir);
 		srv->userdir = NULL;
 	}
+
 	if (srv->userdir_handler != NULL) {
 		cherokee_plugin_table_entry_free (srv->userdir_handler);
 		srv->userdir_handler = NULL;
 	}
 	
+	if (srv->chroot != NULL) {
+		free (srv->chroot);
+		srv->chroot = NULL;
+	}
+
 	free (srv);
 	
 	return ret_ok;
@@ -534,6 +578,7 @@ cherokee_server_step (cherokee_server_t *srv)
 	/* Watch the sockets, look for new connections
 	 */
 	do {
+		cherokee_fdpoll_reset (srv->main_thread->fdpoll, srv->socket);
 		cherokee_fdpoll_watch (srv->main_thread->fdpoll, srv->fdwatch_msecs);
 		ret = look_for_new_connection(srv);
 	} while (ret && (i-- > 0));
@@ -605,3 +650,35 @@ cherokee_server_read_config_string (cherokee_server_t *srv, char *config_string)
 
 	return ret_ok;
 }
+
+
+ret_t 
+cherokee_server_handle_HUP (cherokee_server_t *srv)
+{
+	ret_t ret;
+
+	if (srv->chrooted) {
+		fprintf (stderr, 
+			 "WARNING: Chrooted cherokee cannot be reloaded. "
+			 "Please, stop and restart it again.\n");
+		return ret_ok;
+	}
+
+
+	ret = cherokee_server_clean (srv);
+	if (ret != ret_ok) {
+		exit(EXIT_SERVER_CLEAN);
+	}
+
+	ret = cherokee_server_read_config_file (srv, CHEROKEE_CONFDIR"/cherokee.conf");
+	if (ret != ret_ok) {
+		exit(EXIT_SERVER_READ_CONFIG);
+	}
+
+	ret = cherokee_server_init (srv);
+	if (ret != ret_ok) {
+		exit(EXIT_SERVER_INIT);	
+	}
+
+	return ret_ok;
+}
