@@ -53,7 +53,7 @@ typedef struct {
 	cherokee_table_t          *vservers;
 	cherokee_virtual_server_t *vserver_default;
 	
-	/* lists
+	/* Threads
 	 */
 	list_t             thread_list;
 	cherokee_thread_t *main_thread;
@@ -62,6 +62,10 @@ typedef struct {
 	 */
 	cherokee_encoder_table_t *encoders;
 
+	/* Default index files
+	 */
+	list_t index_list;
+
 	/* Logging
 	 */
 	int    log_flush_elapse;
@@ -82,11 +86,15 @@ typedef struct {
 	int   timeout;
 	int   keepalive;
 	int   hideversion;
+	int   hideservername;
 
-	uid_t user;
-	uid_t user_orig;
-	gid_t group;
-	gid_t group_orig;
+	uid_t  user;
+	uid_t  user_orig;
+	gid_t  group;
+	gid_t  group_orig;
+
+	char  *chroot;
+	int    chrooted;
 
 	char *mimetypes_file;
 
@@ -106,9 +114,13 @@ ret_t cherokee_server_free  (cherokee_server_t  *srv);
 void  cherokee_server_step            (cherokee_server_t  *srv);
 void  cherokee_server_set_min_latency (cherokee_server_t  *srv, int msecs);
 
-ret_t cherokee_server_log   (cherokee_server_t  *srv, int active);
+ret_t cherokee_server_read_config_file    (cherokee_server_t *srv, char *filename);
+ret_t cherokee_server_read_config_string  (cherokee_server_t *srv, char *string);
+
+
+/* System signal callback
+ */
+ret_t cherokee_server_handle_HUP (cherokee_server_t *srv);
 
-ret_t cherokee_server_read_config_file   (cherokee_server_t  *srv, char *filename);
-ret_t cherokee_server_read_config_string (cherokee_server_t  *srv, char *string);
 
 #endif /* __CHEROKEE_SERVER_H__ */
