@@ -238,7 +238,7 @@ process_active_connections (cherokee_thread_t *thd)
 			/* Get the virtual host
 			 */
 			if (conn->host->len > 0) {
-				vserver = cherokee_table_get (srv->vservers, conn->host->buf);
+				vserver = cherokee_table_get_val (srv->vservers, conn->host->buf);
 			}
 			if (vserver == NULL) {
 				vserver = srv->vserver_default;
@@ -264,7 +264,7 @@ process_active_connections (cherokee_thread_t *thd)
 				}
 				
 				if (conn->redirect->len >= 1) {
-					cherokee_connection_send_header (conn, srv->hideversion);
+					cherokee_connection_send_header (conn);
 					maybe_purge_closed_connection (thd, conn);
 					continue;
 				}
@@ -317,7 +317,7 @@ process_active_connections (cherokee_thread_t *thd)
 //		} break;
 			
 		case phase_add_headers:
-			ret = cherokee_connection_send_header (conn, srv->hideversion);
+			ret = cherokee_connection_send_header (conn);
 				
 			if (ret == ret_ok) {				
 				if (conn->method == http_head) {
@@ -326,7 +326,7 @@ process_active_connections (cherokee_thread_t *thd)
 				}
 				
 				if (! http_type_200(conn->error_code)) {
-					cherokee_connection_send_response_page (conn, srv->hideversion);
+					cherokee_connection_send_response_page (conn);
 
 					/* Log the error
 					 */
@@ -397,6 +397,7 @@ process_active_connections (cherokee_thread_t *thd)
 				printf ("eagain en servidor\n");
 				break;
 			default:
+				PRINT_ERROR ("Error code unknown: %d\n", ret);
 				SHOULDNT_HAPPEN; 
 			}
 			
