@@ -33,10 +33,13 @@ cherokee_virtual_server_new (cherokee_virtual_server_t **vserver)
 
 	vsrv->domain = NULL;
 	vsrv->root   = NULL;
+
+	vsrv->logger       = NULL;
+	vsrv->logger_props = NULL;
 	
 	cherokee_plugin_table_new (&vsrv->plugins);
 	return_if_fail (vsrv->plugins!=NULL, ret_nomem);	   
-	
+
 	*vserver = vsrv;
 	
 	return ret_ok;
@@ -55,6 +58,15 @@ cherokee_virtual_server_free (cherokee_virtual_server_t *vserver)
 		free (vserver->root);
 		vserver->root = NULL;
 	}
+
+	if (vserver->logger != NULL) {
+		cherokee_logger_free (vserver->logger);
+		vserver->logger = NULL;
+	}
+	if (vserver->logger_props != NULL) {
+		cherokee_table_free (vserver->logger_props);
+		vserver->logger_props = NULL;
+	}
 	
 	cherokee_plugin_table_free (vserver->plugins);
 	vserver->plugins = NULL;
@@ -65,6 +77,7 @@ cherokee_virtual_server_free (cherokee_virtual_server_t *vserver)
 }
 
 
+
 ret_t 
 cherokee_virtual_server_clean (cherokee_virtual_server_t *vserver)
 {
@@ -78,6 +91,15 @@ cherokee_virtual_server_clean (cherokee_virtual_server_t *vserver)
 		vserver->root = NULL;
 	}
 	
+	if (vserver->logger != NULL) {
+		cherokee_logger_free (vserver->logger);
+		vserver->logger = NULL;
+	}
+	if (vserver->logger_props != NULL) {
+		cherokee_table_free (vserver->logger_props);
+		vserver->logger_props = NULL;
+	}
+
 	return ret_ok;
 }
 
