@@ -29,7 +29,7 @@
 #include "common.h"
 #include "plugin_table.h"
 #include "plugin_table_entry.h"
-
+#include "logger.h"
 
 typedef struct {
 	char                    *domain;       /* Domain name. Eg: www.alobbs.com */
@@ -37,8 +37,14 @@ typedef struct {
 
 	char                    *root;         /* Document root. Eg: /var/www */
 	int                      root_len;     /* Document root length */
+
+	cherokee_logger_t       *logger;
+	cherokee_table_t        *logger_props;
 } cherokee_virtual_server_t;
 
+#define VSERVER(v)        ((cherokee_virtual_server_t *)(v))
+#define VSERVER_LOGGER(v) (LOGGER(VSERVER(v)->logger))
+
 ret_t cherokee_virtual_server_new   (cherokee_virtual_server_t **vserver);
 ret_t cherokee_virtual_server_free  (cherokee_virtual_server_t  *vserver);
 ret_t cherokee_virtual_server_clean (cherokee_virtual_server_t  *vserver);
